@@ -70,7 +70,7 @@ is_close:{is_close}
             message_log = self.message_log.format(absolute_path=self.absolute_path, content=content, is_close=is_close)
 
             self.sock.sendall(message_log.encode('utf8'))
-            self.sock.sendall("\n".encode('utf8'))
+            self.sock.send(b'')
         except Exception:
             # 这里发送失败可能是因为: 服务器进程崩溃, 网络问题.
             # 这里可以尝试不做处理, 避免因为日志组件的异常导致对应服务的异常.
